pub struct DistributedContext { /* private fields */ }Expand description
A handle to the distributed runtime.
Implementations
Sourceimpl DistributedContext
impl DistributedContext
Sourcepub fn new(backend: Box<dyn DistributedBackend>) -> Self
pub fn new(backend: Box<dyn DistributedBackend>) -> Self
Create a new distributed context with the given backend.
Sourcepub fn with_metrics(
backend: Box<dyn DistributedBackend>,
metrics: SharedMetrics,
) -> Self
pub fn with_metrics( backend: Box<dyn DistributedBackend>, metrics: SharedMetrics, ) -> Self
Create a new distributed context with metrics enabled.
Sourcepub fn world_size(&self) -> usize
pub fn world_size(&self) -> usize
Get the total number of nodes in the cluster.
Sourcepub async fn all_reduce(&self, buffer: &mut [u8], op: ReduceOp) -> Result<()>
pub async fn all_reduce(&self, buffer: &mut [u8], op: ReduceOp) -> Result<()>
Perform an all-reduce operation on the buffer.
After this call, all nodes will have the same values in their buffers.
op controls whether the result is a sum or mean across nodes.
Sourcepub async fn barrier(&self) -> Result<()>
pub async fn barrier(&self) -> Result<()>
Synchronize all nodes at a barrier.
All nodes must call this method, and none will proceed until all have.
Sourcepub fn metrics_snapshot(&self) -> Option<MetricsSnapshot>
pub fn metrics_snapshot(&self) -> Option<MetricsSnapshot>
Get metrics snapshot if enabled.